@@ -1,5 +1,6 @@
 #![allow(missing_docs)]
 #![allow(missing_docs)]
+use terra_rust_api::errors::TerraRustAPIError;
 use thiserror::Error;
 
 #[derive(Error, Debug)]
@@ -8,7 +9,10 @@ pub enum TerraRustWalletError {
     KeyringError(#[from] KeyringErrorAdapter),
     #[error(transparent)]
     SerdeJsonError(#[from] ::serde_json::Error),
-
+    #[error(transparent)]
+    KeyringErrorAdapter(#[from] ::keyring::Error),
+    #[error(transparent)]
+    TerraRustAPIError(#[from] TerraRustAPIError),
     #[error("Terra Wallet `{key}` Key not found Error")]
     KeyNotFound {
         key: String,
@@ -28,8 +32,8 @@ pub enum TerraRustWalletError {
 #[error(transparent)]
 pub struct KeyringErrorAdapter(anyhow::Error);
 
-impl From<keyring::KeyringError> for KeyringErrorAdapter {
-    fn from(e: keyring::KeyringError) -> Self {
+impl From<keyring::Error> for KeyringErrorAdapter {
+    fn from(e: keyring::Error) -> Self {
         KeyringErrorAdapter(anyhow::anyhow!("Keyring error: {:?}", e))
     }
 }
